@@ -1,27 +1,25 @@
-# -*- coding: utf-8 -*-
+from .interfaces import ILanguageSchema
+from .interfaces import ILanguageUtility
+from .interfaces import INegotiateLanguage
+from .locales.interfaces import ICcTLDInformation
+from .locales.interfaces import IContentLanguageAvailability
+from .locales.interfaces import ICountryAvailability
+from .negotiate.ptsnegotiator import registerLangPrefsMethod
 from AccessControl import ClassSecurityInfo
 from AccessControl import getSecurityManager
 from operator import itemgetter
-from plone.i18n.interfaces import ILanguageUtility
-from plone.i18n.interfaces import INegotiateLanguage
-from plone.i18n.interfaces import ILanguageSchema
-from plone.i18n.locales.interfaces import ICcTLDInformation
-from plone.i18n.locales.interfaces import IContentLanguageAvailability
-from plone.i18n.locales.interfaces import ICountryAvailability
-from plone.i18n.negotiate.ptsnegotiator import registerLangPrefsMethod
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.interfaces import IDublinCore
 from Products.SiteAccess.VirtualHostMonster import VirtualHostMonster
 from ZODB.POSException import ConflictError
 from zope.component import getMultiAdapter
 from zope.component import getUtility
-from zope.component import queryUtility
 from zope.component.hooks import getSite
 from zope.globalrequest import getRequest
 from zope.interface import implementer
 
 
-class LanguageBinding(object):
+class LanguageBinding:
     """Helper which holding language infos in request."""
 
     security = ClassSecurityInfo()
@@ -65,24 +63,21 @@ def setLanguageBinding(request):
 
 
 def onRequest(object, event):
-    """Set Language headers in the request.
-    """
+    """Set Language headers in the request."""
     request = event.request
 
     return setLanguageBinding(request)
 
 
 @implementer(ILanguageUtility)
-class LanguageUtility(object):
+class LanguageUtility:
 
     # resources that must not use language specific URLs
     exclude_paths = frozenset(
         ("portal_css", "portal_javascripts", "portal_kss", "portal_factory")
     )
 
-    exclude_exts = frozenset(
-        ("css", "js", "kss", "xml", "gif", "jpg", "png", "jpeg")
-    )
+    exclude_exts = frozenset(("css", "js", "kss", "xml", "gif", "jpg", "png", "jpeg"))
 
     @property
     def settings(self):
@@ -112,26 +107,23 @@ class LanguageUtility(object):
         available = self.getAvailableLanguages()
         for i in self.supported_langs:
             if available.get(i):
-                r.append((i, available[i][u"name"]))
+                r.append((i, available[i]["name"]))
         return r
 
     def getAvailableLanguages(self):
-        """Returns the dictionary of available languages.
-        """
-        util = queryUtility(IContentLanguageAvailability)
+        """Returns the dictionary of available languages."""
+        util = getUtility(IContentLanguageAvailability)
         if self.settings.use_combined_language_codes:
-            languages = util.getLanguages(combined=True)
-        else:
-            languages = util.getLanguages()
-        return languages
+            return util.getLanguages(combined=True)
+        return util.getLanguages()
 
     def getCcTLDInformation(self):
-        util = queryUtility(ICcTLDInformation)
+        util = getUtility(ICcTLDInformation)
         return util.getTLDs()
 
     def listAvailableLanguages(self):
         """Returns sorted list of available languages (code, name)."""
-        util = queryUtility(IContentLanguageAvailability)
+        util = getUtility(IContentLanguageAvailability)
         if self.use_combined_language_codes:
             languages = util.getLanguageListing(combined=True)
         else:
@@ -144,20 +136,17 @@ class LanguageUtility(object):
         new_langs = []
         for lang in langs:
             # add language-code to dict
-            langs[lang][u"code"] = lang
+            langs[lang]["code"] = lang
             # flatten outer dict to list to make it sortable
             new_langs.append(langs[lang])
         new_langs.sort(
-            lambda x, y: cmp(
-                x.get(u"native", x.get(u"name")),
-                y.get(u"native", y.get(u"name")),
-            )
+            key=lambda x: x.get("native", x.get("name")),
         )
         return new_langs
 
     def getAvailableLanguageInformation(self):
         """Returns the dictionary of available languages."""
-        util = queryUtility(IContentLanguageAvailability)
+        util = getUtility(IContentLanguageAvailability)
         if self.use_combined_language_codes:
             languages = util.getLanguages(combined=True)
         else:
@@ -165,10 +154,7 @@ class LanguageUtility(object):
 
         for lang in languages:
             languages[lang]["code"] = lang
-            if lang in self.supported_langs:
-                languages[lang]["selected"] = True
-            else:
-                languages[lang]["selected"] = False
+            languages[lang]["selected"] = lang in self.supported_langs
         return languages
 
     def getDefaultLanguage(self):
@@ -182,22 +168,22 @@ class LanguageUtility(object):
             if len(self.settings.available_languages) > 0:
                 self.settings.default_language = self.settings.available_languages[
                     0
-                ]  # noqa
+                ]
             return
         self.settings.default_language = langCode
 
     def getNameForLanguageCode(self, langCode):
         """Returns the name for a language code."""
         info = self.getAvailableLanguageInformation().get(langCode, None)
-        if info is not None:
-            return info.get(u"name", None)
-        return None
+        if info is None:
+            return None
+        return info.get("name", None)
 
     def getFlagForLanguageCode(self, langCode):
         """Returns the name of the flag for a language code."""
         info = self.getAvailableLanguageInformation().get(langCode, None)
         if info is not None:
-            return info.get(u"flag", None)
+            return info.get("flag", None)
         return None
 
     def addSupportedLanguage(self, langCode):
@@ -243,8 +229,6 @@ class LanguageUtility(object):
         if lb[0]:
             if not self.settings.use_combined_language_codes:
                 return lb[0].split("-")[0]
-            else:
-                return lb[0]
             return lb[0]
         # this is the default language
         return lb[1]
@@ -276,9 +260,7 @@ class LanguageUtility(object):
 
             # Now check if we need to exclude from using language specific path
             # See https://dev.plone.org/ticket/11263
-            if bool(
-                [1 for p in self.exclude_paths if p in contentpath]
-            ) or bool(
+            if bool([1 for p in self.exclude_paths if p in contentpath]) or bool(
                 [1 for p in self.exclude_exts if contentpath[0].endswith(p)]
             ):
                 return None
@@ -305,8 +287,7 @@ class LanguageUtility(object):
                         continue
                     if lang in self.getSupportedLanguages():
                         return lang
-                    else:
-                        return None
+                    return None
         except ConflictError:
             raise
         except:
@@ -414,12 +395,12 @@ class LanguageUtility(object):
 
     def getAvailableCountries(self):
         """Returns the dictionary of available countries."""
-        util = queryUtility(ICountryAvailability)
+        util = getUtility(ICountryAvailability)
         return util.getCountries()
 
     def listAvailableCountries(self):
         """Returns the sorted list of available countries (code, name)."""
-        util = queryUtility(ICountryAvailability)
+        util = getUtility(ICountryAvailability)
         countries = util.getCountryListing()
         countries.sort(lambda x, y: cmp(x[1], y[1]))
         return countries
@@ -436,14 +417,11 @@ class LanguageUtility(object):
         """Returns True if the selector viewlet should be shown."""
         return self.settings.always_show_selector or (
             self.settings.use_cookie_negotiation
-            and not (
-                self.settings.authenticated_users_only
-                and self.isAnonymousUser()
-            )
+            and not (self.settings.authenticated_users_only and self.isAnonymousUser())
         )
 
 
-class PrefsForPTS(object):
+class PrefsForPTS:
     """A preference to hook into PTS."""
 
     def __init__(self, context):
